@@ -15,7 +15,6 @@
 #' @param add_to_data return also the original data frame with an extra 'clust' column with the cluster ids ('id' is the first column)
 #' @param hclust_intra_clusters run hierarchical clustering within each cluster and return an ordering of the observations.
 #' @param seed seed for the c++ random number generator
-#' @param parallel cluster every cluster parallelly (if hclust_intra_clusters is true)
 #' @param use_cpp_random use c++ random number generator instead of R's. This should be used for only for
 #' backwards compatibility, as from version 0.4.0 onwards the default random number generator was changed o R.
 #'
@@ -65,7 +64,6 @@ TGL_kmeans_tidy <- function(df,
                             add_to_data = FALSE,
                             hclust_intra_clusters = FALSE,
                             seed = NULL,
-                            parallel = getOption("tglkmeans.parallel"),
                             use_cpp_random = FALSE) {
     if (!is.null(seed)) {
         set.seed(seed)
@@ -103,7 +101,7 @@ TGL_kmeans_tidy <- function(df,
     if (id_column) {
         ids <- as.character(df[, 1])
         id_column_name <- colnames(df)[1]
-        df <- df[, -1]
+        df <- df[, -1, drop = FALSE]
     }
 
     mat <- df
@@ -207,7 +205,7 @@ TGL_kmeans_tidy <- function(df,
         }
         full_data <- full_data %>%
             select(clust, !!id_column_name, everything())
-        km$order <- hclust_every_cluster(km, full_data, parallel = parallel)
+        km$order <- hclust_every_cluster(km, full_data, parallel = FALSE)
     }
 
     return(km)
@@ -256,7 +254,8 @@ reorder_clusters <- function(km, func = "hclust") {
 
     if (identical(func, "hclust") ||
         identical(func, hclust)) {
-        if (min(apply(km$centers[, -1], 1, var, na.rm = TRUE), na.rm = TRUE) == 0) {
+        vars <- apply(km$centers[, -1], 1, var, na.rm = TRUE)
+        if (!all(is.na(vars)) && min(vars, na.rm = TRUE) == 0) {
             cli_warn("standard deviation of kmeans center is 0")
         } else {
             cm <- km$centers[, -1] %>%
@@ -341,7 +340,6 @@ TGL_kmeans <- function(df,
                        reorder_func = "hclust",
                        hclust_intra_clusters = FALSE,
                        seed = NULL,
-                       parallel = getOption("tglkmeans.parallel"),
                        use_cpp_random = FALSE) {
     res <- TGL_kmeans_tidy(
         df = df,
@@ -355,7 +353,6 @@ TGL_kmeans <- function(df,
         reorder_func = reorder_func,
         seed = seed,
         hclust_intra_clusters = hclust_intra_clusters,
-        parallel = parallel,
         use_cpp_random = use_cpp_random
     )
 
